@@ -312,6 +312,7 @@ def num_neurons():  # type: () -> int
         neuron_cores = 0
         for item in j:
             neuron_cores += item.get("nc_count", 0)
+        logger.info(f"Found {neuron_cores} neurons on this instance")
         return neuron_cores
     except OSError:
         logger.info("No Neurons detected (normal if no neurons installed)")
@@ -358,6 +359,24 @@ def num_cpus():  # type: () -> int
     return multiprocessing.cpu_count()
 
 
+def validate_smddpmprun():  # type: () -> bool
+    """Whether smddpmprun is installed.
+
+    Returns:
+        bool: True if both are installed
+    """
+    try:
+        output = subprocess.run(
+            ["which", "smddpmprun"],
+            capture_output=True,
+            text=True,
+            check=True,
+        )
+        return output.stdout != ""
+    except subprocess.CalledProcessError:
+        return False
+
+
 class Environment(mapping.MappingMixin):  # pylint:disable=too-many-public-methods
     """Provides access to aspects of the training environment relevant to training jobs, including
     hyperparameters, system characteristics, filesystem locations, environment variables and
@@ -650,6 +669,7 @@ class Environment(mapping.MappingMixin):  # pylint:disable=too-many-public-metho
 
         mp_parameters = os.environ.get(params.SM_HP_MP_PARAMETERS)
         self._is_modelparallel_enabled = mp_parameters and mp_parameters != "{}"
+        self._is_smddpmprun_installed = validate_smddpmprun()
 
     @property
     def current_instance_type(self):
@@ -857,6 +877,9 @@ class Environment(mapping.MappingMixin):  # pylint:disable=too-many-public-metho
             or self._additional_framework_parameters.get(
                 "sagemaker_multi_worker_mirrored_strategy_enabled", False
             )
+            or self._additional_framework_parameters.get(
+                "sagemaker_torch_distributed_enabled", False
+            )
         ):
             distribution_instance_groups.append(current_instance_group)
         return distribution_instance_groups
@@ -1176,6 +1199,15 @@ class Environment(mapping.MappingMixin):  # pylint:disable=too-many-public-metho
         """
         return self._is_modelparallel_enabled
 
+    @property
+    def is_smddpmprun_installed(self):  # type: () -> bool
+        """Whether smddpmprun is installed.
+
+        Returns:
+            bool: True if both are installed
+        """
+        return self._is_smddpmprun_installed
+
 
 def write_env_vars(env_vars=None):  # type: (dict) -> None
     """Write the dictionary env_vars in the system, as environment variables.
