@@ -22,6 +22,10 @@ class ClientError(Exception):
     """Error class used to separate framework and user errors."""
 
 
+class SMTrainingCompilerConfigurationError(Exception):
+    """Error class used to separate configuration errors"""
+
+
 class _CalledProcessError(ClientError):
     """This exception is raised when a process run by check_call() or
     check_output() returns a non-zero exit status.
